pub struct TransferRecipient {
pub recipient: String,
pub amount: Coin,
}Fields
recipient: Stringamount: CoinTrait Implementations
Sourceimpl Clone for TransferRecipient
impl Clone for TransferRecipient
Sourcefn clone(&self) -> TransferRecipient
fn clone(&self) -> TransferRecipient
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferRecipient
impl Debug for TransferRecipient
Sourceimpl<'de> Deserialize<'de> for TransferRecipient
impl<'de> Deserialize<'de> for TransferRecipient
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TransferRecipient
impl JsonSchema for TransferRecipient
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TransferRecipient
impl PartialEq for TransferRecipient
Sourceimpl Serialize for TransferRecipient
impl Serialize for TransferRecipient
impl StructuralPartialEq for TransferRecipient